@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 13011 2021-06-26 08:27:23Z Casey $
+# $Id: Backends.py 13097 2021-07-23 06:08:15Z Mint $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,16 +11,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $
-# $Date: 2021-06-26 16:27:23 +0800 (Sat, 26 Jun 2021) $
-# $Revision: 13011 $
+# $Author: Mint $
+# $Date: 2021-07-23 14:08:15 +0800 (週五, 23 七月 2021) $
+# $Revision: 13097 $
 
 import re
 import os
 import sys
 import json
 import requests
-
+import django
+    
 from passlib.apache import HtpasswdFile
 
 from django.conf import settings
@@ -28,6 +29,12 @@ from django.core.exceptions import PermissionDenied
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
 
+from Iuppiter.DjangoUtil import DJANGO_VERSION
+if(DJANGO_VERSION >= 30000):
+    from django.contrib.auth.backends import BaseBackend
+else:
+    BaseBackend = object
+    
 DEFAULT_TRAC_AUTH_URL = getattr(settings, 
     'DEFAULT_TRAC_AUTH_URL', 'https://code.nuwainfo.com/aec359bc3cfadb7504f26461a4c06625')
 DEFAULT_TRAC_AUTH_USERNAME = getattr(settings, 'DEFAULT_TRAC_AUTH_USERNAME', 'Deploy')
@@ -37,7 +44,7 @@ SET_TRAC_LOGIN_AS_SUPERUSER = getattr(settings, "SET_TRAC_LOGIN_AS_SUPERUSER", F
 
 USER_DATA_PATTERN = "#\s+?(\w+):\s+?(\{.+\}?)"
   
-class TracBackend(ModelBackend):
+class TracBackend(BaseBackend):
 
     def check(self, username, password, tracAuthURL=DEFAULT_TRAC_AUTH_URL, 
         tracUsername=DEFAULT_TRAC_AUTH_USERNAME, tracPassword=DEFAULT_TRAC_AUTH_PASSWORD):
@@ -67,4 +74,4 @@ class TracBackend(ModelBackend):
                 user.is_superuser = SET_TRAC_LOGIN_AS_SUPERUSER
                 user.save()
             return user
-        return None
\ No newline at end of file
+        return None
